import { useEffect, useState } from "react";
import ItemCard from "@/components/ItemCard";
import { Input, Empty, Spin } from "antd";
import { GetAppList } from "@/api/appStore";
import { useRequest, history } from "umi";
import { INDUSTRIE_OPTIONS, APPLICATION_SCENARIOS_OPTIONS } from "@/constants";
import noDataImg from "@/assets/no-data.svg";

type SceneItem = {
  label: string;
  value: string;
  icon?: JSX.Element;
};
const industrys = [{ label: "全部行业", value: "all" }, ...INDUSTRIE_OPTIONS];

const scenes: SceneItem[] = [
  {
    label: "推荐",
    icon: <i className="iconfont icon-tuijian mr-1" />,
    value: "recommend",
  },
  ...APPLICATION_SCENARIOS_OPTIONS,
];
export default function Home() {
  const [search, setSearch] = useState("");
  const [industryFilter, setIndustryFilter] = useState("all");
  const [sceneFilter, setSceneFilter] = useState("recommend");
  const { data, run, loading } = useRequest(GetAppList, {
    defaultParams: [
      {
        currentPage: 1,
        pageSize: 1000,
        filters: [
          { name: "isDel", value: 0 },
          { name: "isOnMarket", value: 1 },
        ],
      },
    ],
  });

  useEffect(() => {
    run({
      currentPage: 1,
      pageSize: 1000,
      filters: [
        { name: "isDel", value: 0 },
        { name: "isOnMarket", value: 1 },
        { name: "name", value: search },
        {
          name: "industries",
          value: industryFilter === "all" ? "" : industryFilter,
        },
        {
          name: "applicationScenarios",
          value: sceneFilter === "recommend" ? "" : sceneFilter,
        },
      ],
    });
  }, [industryFilter, sceneFilter, search]);

  const handleToAppDetail = (id: string) => {
    history.push(`/detail/application/${id}`);
  };

  return (
    <div className="flex h-full">
      <div className="left w-fit sm:w-[216px] shrink-0 pt-6 px-4 border-gray-200 border-0 border-r border-solid border-gray-200">
        <ul className="flex flex-col gap-y-2">
          {industrys.map((item) => (
            <li
              key={item.value}
              className={`cursor-pointer text-14px text-secondary gap-2 flex items-center pc:justify-start pc:w-full mobile:justify-center mobile:w-fit h-9 px-3 mobile:px-2 rounded-lg ${industryFilter === item.value ? "bg-white font-semibold !text-primary shadow-xs" : ""}`}
              onClick={() => setIndustryFilter(item.value)}
            >
              <span>{item.label}</span>
            </li>
          ))}
        </ul>
      </div>
      <div className="right flex-1 pt-6 px-4 h-full flex flex-col">
        <div className="shrink-0 pt-6 px-12">
          <div className="mb-1 text-primary text-xl font-semibold">
            探索应用模版
          </div>
          <div className="text-gray-500 text-sm">
            使用这些模板应用程序，或根据模板自定义您自己的应用程序。
          </div>
        </div>
        <div className="flex items-center justify-between mt-6 px-12">
          <div className="flex space-x-1 text-[13px] flex-wrap">
            {scenes.map((scene) => (
              <div
                key={scene.value}
                className={`cursor-pointer px-3 py-[7px] h-[32px] rounded-lg font-medium leading-[18px] cursor-pointer ${scene.value === sceneFilter ? "bg-white shadow-xs text-primary-600 text-primary" : "border-transparent text-gray-700 hover:bg-gray-200"}`}
                onClick={() => setSceneFilter(scene.value)}
              >
                {scene?.icon}
                {scene.label}
              </div>
            ))}
          </div>
          <div>
            <Input
              value={search}
              onChange={(e) => setSearch(e.target.value)}
              placeholder="搜索"
              prefix={<i className="iconfont icon-sousuo" />}
              allowClear
            ></Input>
          </div>
        </div>

        <div className="relative flex flex-1 pb-6 flex-col overflow-auto bg-gray-100 shrink-0 grow mt-4">
          <Spin spinning={loading}>
            <nav
              className="grid content-start shrink-0 gap-4 px-6 sm:px-12"
              style={{ gridTemplateColumns: "repeat(3,minmax(0,1fr))" }}
            >
              {(data?.result?.model || []).map((item: any, index: number) => (
                <ItemCard data={item} key={index} onClick={handleToAppDetail} />
              ))}
            </nav>

            {!data?.result.model.length && !loading && (
              <Empty description="暂无数据" image={noDataImg}/>
            )}
          </Spin>
        </div>
      </div>
    </div>
  );
}
